@@ -25,7 +25,7 @@ export function shimRTCIceCandidate(window) {
     if (typeof args === 'object' && args.candidate &&
         args.candidate.indexOf('a=') === 0) {
       args = JSON.parse(JSON.stringify(args));
-      args.candidate = args.candidate.substr(2);
+      args.candidate = args.candidate.substring(2);
     }
 
     if (args.candidate && args.candidate.length) {
@@ -33,7 +33,7 @@ export function shimRTCIceCandidate(window) {
       const nativeCandidate = new NativeRTCIceCandidate(args);
       const parsedCandidate = SDPUtils.parseCandidate(args.candidate);
       const augmentedCandidate = Object.assign(nativeCandidate,
-          parsedCandidate);
+        parsedCandidate);
 
       // Add a serializer that does not serialize the extra attributes.
       augmentedCandidate.toJSON = function toJSON() {
@@ -173,7 +173,7 @@ export function shimMaxMessageSize(window, browserDetails) {
     const match = SDPUtils.matchPrefix(description.sdp,
       'a=max-message-size:');
     if (match.length > 0) {
-      maxMessageSize = parseInt(match[0].substr(19), 10);
+      maxMessageSize = parseInt(match[0].substring(19), 10);
     } else if (browserDetails.browser === 'firefox' &&
                 remoteIsFirefox !== -1) {
       // If the maximum message size is not present in the remote SDP and
@@ -308,12 +308,12 @@ export function shimConnectionState(window) {
     set(cb) {
       if (this._onconnectionstatechange) {
         this.removeEventListener('connectionstatechange',
-            this._onconnectionstatechange);
+          this._onconnectionstatechange);
         delete this._onconnectionstatechange;
       }
       if (cb) {
         this.addEventListener('connectionstatechange',
-            this._onconnectionstatechange = cb);
+          this._onconnectionstatechange = cb);
       }
     },
     enumerable: true,
